pynrc.NIRCam
============

.. currentmodule:: pynrc

.. autoclass:: NIRCam
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~NIRCam.ND_acq
      ~NIRCam.bandpass
      ~NIRCam.bar_offset
      ~NIRCam.channel
      ~NIRCam.det_info
      ~NIRCam.filter
      ~NIRCam.filter_list
      ~NIRCam.mask
      ~NIRCam.mask_list
      ~NIRCam.module
      ~NIRCam.multiaccum
      ~NIRCam.multiaccum_times
      ~NIRCam.pixelscale
      ~NIRCam.psf_coeff
      ~NIRCam.psf_coeff_bg
      ~NIRCam.psf_info
      ~NIRCam.psf_info_bg
      ~NIRCam.pupil
      ~NIRCam.pupil_list
      ~NIRCam.well_level
      ~NIRCam.wfe_drift

   .. rubric:: Methods Summary

   .. autosummary::

      ~NIRCam.bg_zodi
      ~NIRCam.gen_exposures
      ~NIRCam.gen_psf
      ~NIRCam.plot_bandpass
      ~NIRCam.ramp_optimize
      ~NIRCam.sat_limits
      ~NIRCam.saturation_levels
      ~NIRCam.sensitivity
      ~NIRCam.update_detectors
      ~NIRCam.update_psf_coeff

   .. rubric:: Methods Documentation

   .. automethod:: bg_zodi
   .. automethod:: gen_exposures
   .. automethod:: gen_psf
   .. automethod:: plot_bandpass
   .. automethod:: ramp_optimize
   .. automethod:: sat_limits
   .. automethod:: saturation_levels
   .. automethod:: sensitivity
   .. automethod:: update_detectors
   .. automethod:: update_psf_coeff
